==> mgb-0.5.4.1-de.zip: language/lang_update.php <==
<?php
// DO NOT REMOVE THIS COPYRIGHT //
//
// MGB v.null.fuenf (0.5.4.1) (C) by Jrgen Grneisl
// Visit me on http://www.tv-kritik.net/mgb/index.php
//
// This Guestbook is licensed under GNU GPL. Feel free to use, copy, share or modify it. :)

//lang_update.php - Sprachvariablen fr die Installation

////////////////////
// DEUTSCH v1.0.1 //
////////////////////

// Allgemeine Variablen

$lang['license']		= "Mit der Installation und anschlieenden Nutzung dieses Gstebuches,<br>stimmen Sie der GNU GPL Lizenz fr freie Software zu.";

$lang['title']		= "MGB v.null.fuenf (0.5.4) -- Installation";
$lang['greetz']		= "Willkommen zum Update des MGB 0.5.4. Ich mchte mich herzlich bei<br>Dir bedanken da Du auch weiterhin mein Gstebuch benutzt! :) Das Update dauert<br>nur ein paar Minuten, und danach ist Dein Gstebuch sofort auf dem neuesten Stand!";
$lang['instructions']	= "Dies ist die <b>update.php</b> der Version <b>0.5.4</b>! Mit ihr kannst Du folgende Versionen des MGB aktualisieren:<br><br>0.5 - 0.5.3";

$lang['tables']		= "Folgende Tabellen werden verndert";
$lang['button_value']	= "Jetzt aktualisieren";

$lang['success']		= "Das Update auf 0.5.4 wurde erfolgreich durchgefhrt! :) Bitte lsche jetzt die ''update.php''!";
$lang['install_failure'] = "Es ist ein Fehler bei der Verbindung zur Datenbank aufgetreten. berprfe die 'config.php' ob Du alle Daten<br>fr die Verbindung zur Datenbank richtig eingegeben hast.";
$lang['to_gb']		= "Zum Gstebuch";
$lang['to_admin']	= "Zur Administration";
$lang['hf']		= "Viel Spa wnscht";

?>

==> mgb-0.5.4.2-de.zip: language/lang_update.php <==
<?php
	/*
	MGB 0.5.4.2
	Copyright (C) 2004 - 2006  Juergen Grueneisl

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	*/

//lang_update.php - Sprachvariablen fr die Installation

////////////////////
// DEUTSCH v1.0.1 //
////////////////////

// Allgemeine Variablen

$lang['license']		= "Mit der Installation und anschlieenden Nutzung dieses Gstebuches,<br>stimmen Sie der GNU GPL Lizenz fr freie Software zu.";

$lang['title']		= "MGB v.null.fuenf (0.5.4) -- Installation";
$lang['greetz']		= "Willkommen zum Update des MGB 0.5.4. Ich mchte mich herzlich bei<br>Dir bedanken da Du auch weiterhin mein Gstebuch benutzt! :) Das Update dauert<br>nur ein paar Minuten, und danach ist Dein Gstebuch sofort auf dem neuesten Stand!";
$lang['instructions']	= "Dies ist die <b>update.php</b> der Version <b>0.5.4</b>! Mit ihr kannst Du folgende Versionen des MGB aktualisieren:<br><br>0.5 - 0.5.3";

$lang['tables']		= "Folgende Tabellen werden verndert";
$lang['button_value']	= "Jetzt aktualisieren";

$lang['success']		= "Das Update auf 0.5.4 wurde erfolgreich durchgefhrt! :) Bitte lsche jetzt die ''update.php''!";
$lang['install_failure'] = "Es ist ein Fehler bei der Verbindung zur Datenbank aufgetreten. berprfe die 'config.php' ob Du alle Daten<br>fr die Verbindung zur Datenbank richtig eingegeben hast.";
$lang['to_gb']		= "Zum Gstebuch";
$lang['to_admin']	= "Zur Administration";
$lang['hf']		= "Viel Spa wnscht";

?>
